# Modifications to GnuTLS to build on Android.
# Copyright (C) 2023-2024 Free Software Foundation, Inc.

# These modifications are part of GNU Emacs.

# GNU Emacs is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.

# GNU Emacs is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.

LOCAL_PATH := $(call my-dir)

# Static libgnu_gnutls module.
include $(CLEAR_VARS)
LOCAL_C_INCLUDES := $(LOCAL_PATH) $(LOCAL_PATH)/..

WARN_CFLAGS = -fno-common -Wbad-function-cast				\
  -Wdisabled-optimization -Wdouble-promotion -Wextra -Winit-self	\
  -Winvalid-pch -Wmissing-declarations -Wmissing-include-dirs		\
  -Wmissing-prototypes -Wnested-externs -Wold-style-definition		\
  -Wpacked -Wpointer-arith -Wshadow					\
  -Wstrict-prototypes -Wuninitialized -Wunknown-pragmas			\
  -Wvariadic-macros -Wwrite-strings -Wformat=2				\
  -Wno-missing-field-initializers -Wno-unused-parameter			\
  -fdiagnostics-show-option -fno-builtin-strcmp -Wno-sign-compare

# Import source files from Makefile.am.
libgnu_la_SOURCES = basename-lgpl.c \
	bitrotate.h \
	bitrotate.c \
	c-ctype.h \
	c-ctype.c \
	c-strcase.h \
	c-strcasecmp.c \
	c-strncasecmp.c \
	canonicalize-lgpl.c \
	cloexec.c  \
	dirname-lgpl.c \
	stripslash.c \
	dup2.c \
	explicit_bzero.c \
	fcntl.c \
	fd-hook.c   \
	free.c    \
	getdelim.c \
	getdtablesize.c \
	getline.c \
	gettext.h  \
	malloc/scratch_buffer_grow.c \
	malloc/scratch_buffer_grow_preserve.c \
	malloc/scratch_buffer_set_array_size.c \
	hash.c \
	hash-pjw-bare.h \
	hash-pjw-bare.c \
	idx.h   \
	gl_linkedhash_list.h \
	gl_linkedhash_list.c \
	gl_anyhash1.h \
	gl_anyhash2.h \
	gl_anyhash_primes.h \
	gl_anylinked_list1.h \
	gl_anylinked_list2.h \
	gl_list.h \
	gl_list.c \
	glthread/lock.h \
	glthread/lock.c  \
	malloca.c \
	memchr.c \
	mempcpy.c \
	memset_explicit.c \
	minmax.h    \
	rawmemchr.c \
	read-file.c  \
	secure_getenv.c  \
	size_max.h  \
	stat-time.c   \
	stpcpy.c       \
	strverscmp.c \
	sys_socket.c \
	glthread/threadlib.c  \
	glthread/tls.h \
	glthread/tls.c \
	unistd.c      \
	xsize.h \
	xsize.c

EXTRA_libgnu_la_SOURCES = alloca.c \
	fopen.c \
	malloc.c \
	memmem.c \
	realloc.c \
	stat-w32.c

LOCAL_SRC_FILES := $(call libgnutls_filter_sources,$(libgnu_la_SOURCES) \
		      $(EXTRA_libgnu_la_SOURCES))
LOCAL_MODULE := libgnu_gnutls
LOCAL_CFLAGS := $(libgnutls_common_CFLAGS) $(WARN_CFLAGS) \
  -DGNULIB_defined_F_DUPFD_CLOEXEC=1			  \
  -DO_BINARY=0 -fvisibility=hidden

include $(BUILD_STATIC_LIBRARY)
