# Modifications to libjpeg-turbo to build on Android.
# Copyright (C) 2024 Free Software Foundation, Inc.

# These modifications are part of GNU Emacs.

# GNU Emacs is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.

# GNU Emacs is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.

LOCAL_PATH := $(call my-dir)

JPEG16_SOURCES = jcapistd.c jccolor.c jcdiffct.c jclossls.c jcmainct.c \
  jcprepct.c jcsample.c jdapistd.c jdcolor.c jddiffct.c jdlossls.c jdmainct.c \
  jdpostct.c jdsample.c jutils.c
JPEG12_SOURCES = ${JPEG16_SOURCES} jccoefct.c jcdctmgr.c jdcoefct.c \
  jddctmgr.c jdmerge.c jfdctfst.c jfdctint.c jidctflt.c jidctfst.c jidctint.c \
  jidctred.c jquant1.c jquant2.c
JPEG_SOURCES = ${JPEG12_SOURCES} jcapimin.c jchuff.c jcicc.c jcinit.c \
  jclhuff.c jcmarker.c jcmaster.c jcomapi.c jcparam.c jcphuff.c jctrans.c \
  jdapimin.c jdatadst.c jdatasrc.c jdhuff.c jdicc.c jdinput.c jdlhuff.c \
  jdmarker.c jdmaster.c jdphuff.c jdtrans.c jerror.c jfdctflt.c jmemmgr.c \
  jmemnobs.c jpeg_nbits.c jaricom.c jcarith.c jdarith.c

SIMD_SOURCES_x86_64 = x86_64/jsimdcpu.asm x86_64/jfdctflt-sse.asm \
    x86_64/jccolor-sse2.asm x86_64/jcgray-sse2.asm x86_64/jchuff-sse2.asm \
    x86_64/jcphuff-sse2.asm x86_64/jcsample-sse2.asm x86_64/jdcolor-sse2.asm \
    x86_64/jdmerge-sse2.asm x86_64/jdsample-sse2.asm x86_64/jfdctfst-sse2.asm \
    x86_64/jfdctint-sse2.asm x86_64/jidctflt-sse2.asm x86_64/jidctfst-sse2.asm \
    x86_64/jidctint-sse2.asm x86_64/jidctred-sse2.asm x86_64/jquantf-sse2.asm \
    x86_64/jquanti-sse2.asm \
    x86_64/jccolor-avx2.asm x86_64/jcgray-avx2.asm x86_64/jcsample-avx2.asm \
    x86_64/jdcolor-avx2.asm x86_64/jdmerge-avx2.asm x86_64/jdsample-avx2.asm \
    x86_64/jfdctint-avx2.asm x86_64/jidctint-avx2.asm x86_64/jquanti-avx2.asm \
    x86_64/jsimd.c

SIMD_SOURCES_x86 = i386/jsimdcpu.asm i386/jfdctflt-3dn.asm \
    i386/jidctflt-3dn.asm i386/jquant-3dn.asm \
    i386/jccolor-mmx.asm i386/jcgray-mmx.asm i386/jcsample-mmx.asm \
    i386/jdcolor-mmx.asm i386/jdmerge-mmx.asm i386/jdsample-mmx.asm \
    i386/jfdctfst-mmx.asm i386/jfdctint-mmx.asm i386/jidctfst-mmx.asm \
    i386/jidctint-mmx.asm i386/jidctred-mmx.asm i386/jquant-mmx.asm \
    i386/jfdctflt-sse.asm i386/jidctflt-sse.asm i386/jquant-sse.asm \
    i386/jccolor-sse2.asm i386/jcgray-sse2.asm i386/jchuff-sse2.asm \
    i386/jcphuff-sse2.asm i386/jcsample-sse2.asm i386/jdcolor-sse2.asm \
    i386/jdmerge-sse2.asm i386/jdsample-sse2.asm i386/jfdctfst-sse2.asm \
    i386/jfdctint-sse2.asm i386/jidctflt-sse2.asm i386/jidctfst-sse2.asm \
    i386/jidctint-sse2.asm i386/jidctred-sse2.asm i386/jquantf-sse2.asm \
    i386/jquanti-sse2.asm \
    i386/jccolor-avx2.asm i386/jcgray-avx2.asm i386/jcsample-avx2.asm \
    i386/jdcolor-avx2.asm i386/jdmerge-avx2.asm i386/jdsample-avx2.asm \
    i386/jfdctint-avx2.asm i386/jidctint-avx2.asm i386/jquanti-avx2.asm \
    i386/jsimd.c

SIMD_SOURCES_mips = mips/jsimd_dspr2.S mips/jsimd.c

ifneq ($(findstring 64,$(TARGET_ARCH)),)
SIZEOF_SIZE_T := 8
BITS := 64
else
SIZEOF_SIZE_T := 4
BITS := 32
endif

SIMD_SOURCES_arm_base = arm/jcgray-neon.c arm/jcphuff-neon.c arm/jcsample-neon.c \
  arm/jdmerge-neon.c arm/jdsample-neon.c arm/jfdctfst-neon.c \
  arm/jidctred-neon.c arm/jquanti-neon.c arm/jccolor-neon.c
SIMD_SOURCES_arm_neon = $(SIMD_SOURCES_arm_base)  \
  arm/jidctint-neon.c arm/jidctfst-neon.c arm/aarch${BITS}/jchuff-neon.c \
  arm/jdcolor-neon.c arm/jfdctint-neon.c

SIMD_SOURCES_arm64 = $(SIMD_SOURCES_arm_neon) arm/aarch64/jsimd.c
SIMD_SOURCES_arm = $(SIMD_SOURCES_arm_neon) arm/aarch32/jsimd.c

# libjpeg12 and libjpeg16 static libraries.

include $(CLEAR_VARS)
LOCAL_MODULE := libjpeg12
LOCAL_CFLAGS := -O2 -fstrict-aliasing -DSIZEOF_SIZE_T=$(SIZEOF_SIZE_T) \
  -DBITS_IN_JSAMPLE=12
LOCAL_SRC_FILES = $(JPEG12_SOURCES)
include $(BUILD_STATIC_LIBRARY)

include $(CLEAR_VARS)
LOCAL_MODULE := libjpeg16
LOCAL_CFLAGS := -O2 -fstrict-aliasing -DSIZEOF_SIZE_T=$(SIZEOF_SIZE_T) \
  -DBITS_IN_JSAMPLE=16
LOCAL_SRC_FILES = $(JPEG16_SOURCES)
include $(BUILD_STATIC_LIBRARY)

# libjpeg shared library

include $(CLEAR_VARS)

LOCAL_MODULE := libjpeg
LOCAL_STATIC_LIBRARIES := libjpeg12 libjpeg16
LOCAL_SRC_FILES := $(JPEG_SOURCES)
LOCAL_SRC_FILES_arm := $(foreach file,$(SIMD_SOURCES_arm),simd/$(file))
LOCAL_SRC_FILES_arm64 := $(foreach file,$(SIMD_SOURCES_arm64),simd/$(file))
LOCAL_SRC_FILES_mips := $(foreach file,$(SIMD_SOURCES_mips),simd/$(file))
LOCAL_SRC_FILES_x86 := $(foreach file,$(SIMD_SOURCES_x86),simd/$(file))
LOCAL_SRC_FILES_x86_64 := $(foreach file,$(SIMD_SOURCES_x86_64),simd/$(file))

LOCAL_C_INCLUDES :=

ifneq ($(TARGET_ARCH),mips64)
LOCAL_C_INCLUDES := $(LOCAL_PATH)/simd
endif

ifeq ($(TARGET_ARCH),arm64)
LOCAL_C_INCLUDES += $(LOCAL_PATH)/simd/arm
endif

ifeq ($(TARGET_ARCH),arm)
LOCAL_C_INCLUDES += $(LOCAL_PATH)/simd/arm
endif

LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)
LOCAL_CFLAGS := -O2 -fstrict-aliasing -DSIZEOF_SIZE_T=$(SIZEOF_SIZE_T)
LOCAL_CFLAGS_arm := -DNEON_INTRINSICS -mfpu=neon -DWITH_SIMD
LOCAL_CFLAGS_arm64 := -DNEON_INTRINSICS -DWITH_SIMD
LOCAL_CFLAGS_x86 := -DWITH_SIMD
LOCAL_CFLAGS_x86_64 := -DWITH_SIMD
LOCAL_CFLAGS_mips := -DWITH_SIMD
LOCAL_ASFLAGS_x86 := -DPIC -DELF -i $(LOCAL_PATH)/simd/nasm
LOCAL_ASFLAGS_x86_64 := -DPIC -DELF -D__x86_64__ -i $(LOCAL_PATH)/simd/nasm
include $(BUILD_SHARED_LIBRARY)
