# Modifications to Pango to build on Android.
# Copyright (C) 2024 Free Software Foundation, Inc.

# These modifications are part of GNU Emacs.

# GNU Emacs is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.

# GNU Emacs is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.

LOCAL_PATH := $(call my-dir)
pango_SAVE_LOCAL_PATH := $(LOCAL_PATH)

include $(LOCAL_PATH)/mini-fribidi/Android.mk
LOCAL_PATH := $(pango_SAVE_LOCAL_PATH)

include $(CLEAR_VARS)

# Shared library pango.

libpango_1_0_la_SOURCES =			\
	break.c					\
	ellipsize.c				\
	fonts.c					\
	glyphstring.c				\
	modules.c				\
	pango-attributes.c			\
	pango-bidi-type.c			\
	pango-color.c				\
	pango-context.c				\
	pango-coverage.c			\
	pango-engine.c				\
	pango-fontmap.c				\
	pango-fontset.c				\
	pango-glyph-item.c			\
	pango-gravity.c				\
	pango-item.c				\
	pango-language.c			\
	pango-layout.c				\
	pango-markup.c				\
	pango-matrix.c				\
	pango-renderer.c			\
	pango-script.c				\
	pango-tabs.c				\
	pango-utils.c				\
	reorder-items.c				\
	shape.c					\
	pango-enum-types.c

LOCAL_MODULE := pango
LOCAL_SRC_FILES := $(libpango_1_0_la_SOURCES)
LOCAL_SHARED_LIBRARIES := glib gobject
LOCAL_STATIC_LIBRARIES := pango-fribidi
LOCAL_CFLAGS := -O2 -Wimplicit-function-declaration	\
  -Wno-enum-conversion					\
  -DPANGO_ENABLE_BACKEND				\
  -DPANGO_ENABLE_ENGINE					\
  -Wno-deprecated-declarations				\
  -DSYSCONFDIR=\"/data/data/org.gnu.emacs/files/pango\" \
  -DLIBDIR=\"/data/data/org.gnu.emacs/files/pango-lib\"

LOCAL_LDFLAGS := -Wl,--no-undefined
LOCAL_C_INCLUDES := $(LOCAL_PATH) $(LOCAL_PATH)/.. $(LOCAL_PATH)/include
LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)/include

include $(BUILD_SHARED_LIBRARY)
include $(CLEAR_VARS)

# Shared library pango-cairo.

pangocairo_core_sources = \
	pangocairo-context.c    \
	pangocairo-font.c	\
	pangocairo-fontmap.c    \
	pangocairo-render.c

LOCAL_MODULE := pango-cairo
LOCAL_SHARED_LIBRARIES := glib gobject pango cairo
LOCAL_SRC_FILES := $(pangocairo_core_sources)
LOCAL_CFLAGS := -O2 -Wimplicit-function-declaration	\
  -Wno-enum-conversion					\
  -DPANGO_ENABLE_BACKEND				\
  -DPANGO_ENABLE_ENGINE
LOCAL_LDFLAGS := -Wl,--no-undefined
LOCAL_C_INCLUDE_DIRS := $(LOCAL_PATH) $(LOCAL_PATH)/.. $(LOCAL_PATH)/include
LOCAL_EXPORT_C_INCLUDE_DIRS := $(LOCAL_PATH)/include
include $(BUILD_SHARED_LIBRARY)

$(call import-module,glib)
$(call import-module,cairo)
